#
# spec file for package wsdd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wsdd
Version:        0.8
Release:        2.2
Summary:        A Web Service Discovery host daemon
License:        MIT
URL:            https://github.com/christgau/wsdd
Source:         https://github.com/christgau/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.xz
Source1:        %{name}-init.sh
Source2:        %{name}.service.in
%if 0%{suse_version} >= 1599 || 0%{?sle_version} >= 150600
Source3:        %{name}.xml
%endif
Source4:        sysconfig.%{name}
Source5:        %{name}.conf
Source6:        %{name}-user.conf
Patch1:         %{name}-shebang.patch
BuildRequires:  firewall-macros
BuildRequires:  python-rpm-macros
BuildRequires:  sysuser-tools
Requires(post): %fillup_prereq
Supplements:    samba
Supplements:    samba-ad-dc
BuildArch:      noarch
%sysusers_requires

%description
wsdd implements a Web Service Discovery host daemon. This enables (Samba) hosts,
like your local NAS device, to be found by Web Service Discovery Clients like Windows.

Since NetBIOS discovery is not supported by Windows anymore, wsdd makes hosts to
appear in Windows again using the Web Service Discovery method. This is beneficial
for devices running Samba, like NAS or file sharing servers on your local network.

%prep
%autosetup -p1

%build
%sysusers_generate_pre %{SOURCE6} %{name} %{name}-user.conf
%if 0%{suse_version} <= 1500
%if 0%{?sle_version} < 150600
sed -i '1s/python3/python3.10/' src/wsdd.py
%else
sed -i '1s/python3/python3.11/' src/wsdd.py
%endif
%endif

%install
install -m 755 -D src/wsdd.py %{buildroot}%{_sbindir}/%{name}
install -m 644 -D man/wsdd.8 %{buildroot}/%{_mandir}/man8/wsdd.8
install -m 755 -D %{SOURCE1} %{buildroot}%{_libexecdir}/wsdd-init.sh
mkdir -p %{buildroot}%{_unitdir}
sed 's#@LIBEXECDIR@#%{_libexecdir}#' %{SOURCE2} >%{buildroot}%{_unitdir}/wsdd.service
%if 0%{?sle_version} <  150600
install -m 644 -D etc/firewalld/services/wsdd.xml %{buildroot}%{_prefix}/lib/firewalld/services/wsdd.xml
%else
install -m 644 -D %{SOURCE3} %{buildroot}%{_prefix}/lib/firewalld/services/wsdd.xml
%endif
install -m 644 -D etc/firewalld/services/wsdd-http.xml %{buildroot}%{_prefix}/lib/firewalld/services/wsdd-http.xml
install -m 644 -D %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.wsdd
install -m 755 -d %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
mkdir -p %{buildroot}%{_prefix}/lib/tmpfiles.d/
install -m 644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}
mkdir -p %{buildroot}/run/wsdd
mkdir -p %{buildroot}%{_localstatedir}/lib/wsdd
mkdir -p %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE6} %{buildroot}%{_sysusersdir}/
%?python3_fix_shebang

%check

%pre -f %{name}.pre
%service_add_pre wsdd.service

%post
%fillup_only
%service_add_post wsdd.service
%tmpfiles_create %{_tmpfilesdir}/wsdd.conf
%firewalld_reload

%preun
%service_del_preun wsdd.service

%postun
%service_del_postun wsdd.service

%files
%license LICENSE
%doc README.md
%{_sbindir}/%{name}
%{_mandir}/man8/wsdd.8%{?ext_man}
%{_sbindir}/rc%{name}
%{_unitdir}/wsdd.service
%{_libexecdir}/wsdd-init.sh
%{_tmpfilesdir}/wsdd.conf
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/wsdd.xml
%{_prefix}/lib/firewalld/services/wsdd-http.xml
%{_fillupdir}/sysconfig.%{name}
%{_sysusersdir}/%{name}-user.conf
%dir %attr(0755,wsdd,wsdd) %ghost /run/%{name}
%attr(0644,wsdd,wsdd) %ghost /run/%{name}/env-vars

%changelog
* Wed Jun  5 2024 Herbert Graeber <herbert@graeber-clan.de>
- Fix build for Leap 15.6
* Wed Apr  3 2024 Herbert Graeber <herbert@graeber-clan.de>
- Fix build for SLE_15
* Sun Mar 31 2024 Herbert Graeber <herbert@graeber-clan.de>
- Update to version 0.8
  * Configuration files for firewalld added
  * Show device type and allow filtering in API's list command
  * Add option --metadata-timeout to set the timeout for the HTTP-based
    metadata exchange
  * The employed UUID is now read from /etc/{machine-id,hostid} before
    falling by back to the UUID derivation from the host name.
  * Handle addresses with zone id by ignoring the interface part
  * Do not crash with asyncio future error when non-existing interface is
    provided
- Remove some bashism from wsdd-init.sh
- Use the unmodified service files from wsdd for Leap 15.5 and below, else
  reuse ws-discovery-udp service from firewalld
* Fri Feb 23 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Oct 18 2023 Herbert Graeber <herbert@graeber-clan.de>
- Leap 15.6 has no python 3.10 anymore, use 3.11 instead
* Thu Apr  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix previous change: really limit the forced change to python
  3.10 on suse_version <= 1500 (up to SLE/Leap 15); newer products
  already use python 3.10 (or newer) as default.
* Mon Apr  3 2023 Herbert Graeber <herbert@graeber-clan.de>
- Force the use of python 3.10 for openSUSE Leap
* Mon Apr  3 2023 Herbert Graeber <herbert@graeber-clan.de>
- Update to version 0.7.1
  * GitHub workflow for static analyses added (syntax, format, and type checks are performed).
  * Added EnvironmentFile and according example for systemd-based distros.
  * Make wsdd work (again) on MacOS (#139). Thanks to Eugene Gershnik.
  * Application profile for UFW has been added (#169)
  * Use of implicitly present async I/O loop instead created one for API servers. Fixes regression due
    to changed API in Python 3.10 (see #162)
  * Source code is spiced with type hints now.
  * man page moved to section 8.
* Wed Jun 29 2022 Herbert Graeber <herbert@graeber-clan.de>
- Include ws-discovey-udp service from firewalld 1.0 as part of wsdd.xml
* Thu Feb 24 2022 Callum Farmer <gmbr3@opensuse.org>
- Add CONFIG parameter to %%sysusers_generate_pre
* Thu Nov 25 2021 Herbert Graeber <herbert@graeber-clan.de>
- Update sources
* Wed Nov 24 2021 Herbert Graeber <herbert@graeber-clan.de>
- Version 0.7.0
  * Using the server interface it is now possible to start and stop the
    host functionality (discoverable device) without terminating and
    restarting the daemon.
  * Support multiple IP addresses in 'hello' messages from other hosts (#89)
  * Support interfaces with IPv6-only configuration (#94)
  * Re-enable 'probe' command of API (#116)
  * Removed code marked as deprecated starting with Python 3.10.
  * The example systemd unit file now uses DynamicUser instead of the unsafe
    nobody:nobody combination. It also employs the rundir as chroot directory.
  * Code changed to use asyncio instead of selector-based
  * The server interface does not close connections after each command anymore.
  * For the 'list' command of the server interface, the list of discovered
    devices is terminated with a line containing only a single dot ('.')
  * Log device discovery only once per address and interface
- Some systemd hardening
* Tue May 11 2021 Dirk Müller <dmueller@suse.com>
- stop owning directories provided by filesystem rpm (bsc#1184786)
* Wed Apr  7 2021 Herbert Graeber <herbert@graeber-clan.de>
- Remove unneccessary (and deprecated) PermissionsStartOnly=true
  (boo#1184446).
* Thu Mar  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add %%sysusers_requires: we are creating users in pre, thus need
  to ensure to have the tooling ready prior to package installation
  (boo#1183047).
* Mon Mar  1 2021 Herbert Graeber <herbert@graeber-clan.de>
- Use sysuser-tools for creation of the wsdd user and group
- Do not hijack the /run/sysconfig folder anymore
* Sun Feb 28 2021 Herbert Graeber <herbert@graeber-clan.de>
- Add missing '/'
* Sun Feb 28 2021 Herbert Graeber <herbert@graeber-clan.de>
- Fix a missed place for use of %%{_tmpfilesdir}
* Sun Feb 28 2021 Herbert Graeber <herbert@graeber-clan.de>
- Cleanup spec file
  * Use %%{_tmpfilesdir} instead of explicit path
  * Fix requirements for %%fillup_only
* Sun Feb  7 2021 Herbert Graeber <herbert@graeber-clan.de>
- Version 0.6.4
  * send proper HTTP status codes in case of server side errors
  * send unicast and multicast UDP traffic in a standard-compliant fashion
  * add -V/--version option
  * copyright year update
* Thu Jan 14 2021 Herbert Graeber <herbert@graeber-clan.de>
- Version 0.6.3
  * Skip Netlink messages smaller than 4 bytes correctly (#77, and maybe #59).
  * Messages are sent via the correct socket to comply with the intended/specified
    message flow. This also eases the firewall configuration (#72).
  * Include instructions for adding repository keys under Debian/Ubuntu in README.
* Wed Oct 21 2020 Herbert Graeber <herbert@graeber-clan.de>
- Run spec-cleaner
* Tue Oct 20 2020 Herbert Graeber <herbert@graeber-clan.de>
- Version 0.6.2
  * Lowered priority of non-essential, protocol-related and internal log
    messages (#53).
  * Do not use PID in Netlink sockets in order to avoid issues with duplicated
    PIDs, e.g., when Docker is used.
  * Prevent exceptions due to invalid incoming messages.
  * HTTP server address family wrong when interface address is added (#62)
  * Fixed error when interface address is removed (#62)
* Sat Aug 29 2020 Herbert Graeber <herbert@graeber-clan.de>
- Fix use of /usr/lib and /usr/libexec
* Mon Jul  6 2020 Herbert Graeber <herbert@graeber-clan.de>
- Version 0.6.1
  * ignore unknown interface indexes from Netlink message on Linux (caused
    "error in main loop")
  * prevent hosts from not being discovered due to misplaced socket registration
    at selector
* Sun Jun 14 2020 Herbert Graeber <herbert@graeber-clan.de>
- Version 0.6
  * new operation 'discovery' operation mode to scan for other hosts,
    exposed via minimalistic socket-based API
  * improved handling of address changes (prevents termination when
    system is currently starting up but no IP address has been assigned)
  * usage of tentative IPv6 addresses is avoided on Linux
  * chroot now works also an machines with international domain/host name
  * fixed handling of invalid messages
  * improved FreeBSD rc.d script
  * code heavily refactored
* Thu May  7 2020 Herbert Graeber <herbert@graeber-clan.de>
- Fix handling of WSDD_WORKGROUP
- Let WSDD_DOMAIN override WSDD_WORKGROUP
* Sun Apr 26 2020 Herbert Graeber <herbert@graeber-clan.de>
- Use wsdd for user and group of the ghost directories
* Sun Apr 26 2020 Herbert Graeber <herbert@graeber-clan.de>
- Replace wsdd-wrapper by an ExecStartPre script
- Change the "WSD_" variable prefix by "WSDD_"
- Run wsdd as user and group wsdd
- Run wsdd in a chroot folder
- Merge firewall files into one
* Tue Mar 31 2020 Herbert Graeber <herbert@graeber-clan.de>
- Update to version 0.5
- Remove unneeded _service file
* Mon Nov 18 2019 Herbert Graeber <herbert@graeber-clan.de>
- Remove debug output
- Respect libexecdir in systemd service file
* Fri Nov 15 2019 Herbert Graeber <herbert@graeber-clan.de>
- Determine domain, and/or hostname
- Move wssd back to /usr/bin
* Fri Nov 15 2019 Herbert Graeber <herbert@graeber-clan.de>
- Reload firewalld services
- Remove fillup_prereq post requires
* Wed Nov 13 2019 Herbert Graeber <herbert@graeber-clan.de>
- Initial package
